@@ -688,7 +688,7 @@ void QCodeEditor::keyPressEvent(QKeyEvent *e)
             }
 
             auto c = charUnderCursor();
-            for (auto p : qAsConst(m_parentheses))
+            for (auto p : std::as_const(m_parentheses))
             {
                 if (p.tabJumpOut && c == p.right)
                 {
@@ -748,7 +748,7 @@ void QCodeEditor::keyPressEvent(QKeyEvent *e)
         {
             auto pre = charUnderCursor(-1);
             auto nxt = charUnderCursor();
-            for (auto p : qAsConst(m_parentheses))
+            for (auto p : std::as_const(m_parentheses))
             {
                 if (p.autoRemove && p.left == pre && p.right == nxt)
                 {
@@ -788,7 +788,7 @@ void QCodeEditor::keyPressEvent(QKeyEvent *e)
             }
         }
 
-        for (auto p : qAsConst(m_parentheses))
+        for (auto p : std::as_const(m_parentheses))
         {
             if (p.autoComplete)
             {
@@ -968,7 +968,7 @@ bool QCodeEditor::event(QEvent *event)
         QPair<int, int> positionOfTooltip{lineNumber, blockPositionStart};
 
         QString text;
-        for (auto const &e : qAsConst(m_squiggler))
+        for (auto const &e : std::as_const(m_squiggler))
         {
             if (e.m_startPos <= positionOfTooltip && e.m_stopPos >= positionOfTooltip)
             {
