@@ -478,6 +478,7 @@ public:
     this->frame_count_for_this_tick = frames;
 
     // Process inputs of all sorts
+    this->process_all_ports<set_ossia_node_in_port<safe_node_base, T>>();
     this->process_all_ports<process_before_run<safe_node_base, T>>(start, frames);
 
     // Process messages
@@ -553,7 +554,7 @@ public:
   }
 
   template <typename Field, typename Val, std::size_t NField>
-  inline constexpr bool from_ossia_value(
+  OSSIA_INLINE constexpr bool from_ossia_value(
       Field& field, const ossia::value& src, Val& dst, avnd::field_index<NField>)
   {
     oscr::from_ossia_value(field, src, dst);
