@@ -1,8 +1,11 @@
 #pragma once
 
-#include <functional>
-#include <cstdint>
+#include <halp/modules.hpp>
 
+#include <cstdint>
+#include <functional>
+
+HALP_MODULE_EXPORT
 namespace halp
 {
 template<typename... Args>
