@@ -1,9 +1,7 @@
 // This is an open source non-commercial project. Dear PVS-Studio, please check
 // it. PVS-Studio Static Code Analyzer for C, C++ and C#: http://www.viva64.com
-#include <ossia/editor/curve/curve.hpp>
-
-#if defined(__cpp_exceptions)
 #include <ossia/editor/curve/behavior.hpp>
+#include <ossia/editor/curve/curve.hpp>
 #include <ossia/editor/curve/curve_abstract.hpp>
 
 namespace ossia
@@ -37,4 +35,3 @@ void behavior::reset()
   ossia::apply(behavior_reset{}, *this);
 }
 }
-#endif
