@@ -1,10 +1,8 @@
 #!/bin/bash -eux
 
-mkdir build
-cd build
-
-export PATH=$PATH:/c/ossia-sdk/cmake/bin:/c/ossia-sdk/llvm/bin
-cmake -GNinja $BUILD_SOURCESDIRECTORY \
+export PATH="$PATH:/c/ossia-sdk/cmake/bin:/c/ossia-sdk/llvm/bin"
+date
+cmake -GNinja -S "$PWD" -B build \
   -DCMAKE_C_COMPILER=c:/ossia-sdk/llvm/bin/clang.exe \
   -DCMAKE_CXX_COMPILER=c:/ossia-sdk/llvm/bin/clang++.exe \
   -DOSSIA_SDK=c:/ossia-sdk \
@@ -14,7 +12,12 @@ cmake -GNinja $BUILD_SOURCESDIRECTORY \
   -DOSSIA_STATIC_EXPORT=1 \
   -DSCORE_INSTALL_HEADERS=1 \
   -DKFR_ARCH=sse2 \
-  -DSCORE_DEPLOYMENT_BUILD=1
+  -DSCORE_DEPLOYMENT_BUILD=1 \
+  -DCMAKE_C_FLAGS="-g0" \
+  -DCMAKE_CXX_FLAGS="-g0"
+date
+cmake --build build
+date
 
-cmake --build .
-cmake --build . --target package
+cmake --build build --target package
+date
