@@ -7,8 +7,10 @@
 #include <score/graphics/widgets/QGraphicsHSVChooser.hpp>
 #include <score/graphics/widgets/QGraphicsIntSlider.hpp>
 #include <score/graphics/widgets/QGraphicsKnob.hpp>
+#include <score/graphics/widgets/QGraphicsLineEdit.hpp>
 #include <score/graphics/widgets/QGraphicsLogKnob.hpp>
 #include <score/graphics/widgets/QGraphicsLogSlider.hpp>
+#include <score/graphics/widgets/QGraphicsMultiSlider.hpp>
 #include <score/graphics/widgets/QGraphicsNoteChooser.hpp>
 #include <score/graphics/widgets/QGraphicsPixmapButton.hpp>
 #include <score/graphics/widgets/QGraphicsPixmapEnum.hpp>
@@ -17,7 +19,10 @@
 #include <score/graphics/widgets/QGraphicsSelectablePixmapToggle.hpp>
 #include <score/graphics/widgets/QGraphicsSlider.hpp>
 #include <score/graphics/widgets/QGraphicsSliderBase.hpp>
+#include <score/graphics/widgets/QGraphicsTextButton.hpp>
 #include <score/graphics/widgets/QGraphicsTimeChooser.hpp>
 #include <score/graphics/widgets/QGraphicsToggle.hpp>
 #include <score/graphics/widgets/QGraphicsXYChooser.hpp>
+#include <score/graphics/widgets/QGraphicsXYSpinbox.hpp>
 #include <score/graphics/widgets/QGraphicsXYZChooser.hpp>
+#include <score/graphics/widgets/QGraphicsXYZSpinbox.hpp>
