@@ -9,33 +9,35 @@
 #include <verdigris>
 namespace score
 {
-struct DefaultGraphicsSpinboxImpl;
 class SCORE_LIB_BASE_EXPORT QGraphicsSpinbox final
     : public QObject
     , public QGraphicsItem
 {
   W_OBJECT(QGraphicsSpinbox)
-  Q_INTERFACES(QGraphicsItem)
+  SCORE_GRAPHICS_ITEM_TYPE(200)
   Q_DISABLE_COPY(QGraphicsSpinbox)
 
+  friend struct DefaultControlImpl;
   friend struct DefaultGraphicsSpinboxImpl;
   QRectF m_rect{0., 0., 40., 20.};
 
 private:
-  float m_value{}, m_execValue{};
+  double m_value{}, m_execValue{};
   bool m_grab{};
   bool m_hasExec{};
+  bool m_noValueChangeOnMove{};
 
 public:
-  float min{}, max{};
+  float min{}, max{}, init{};
   explicit QGraphicsSpinbox(QGraphicsItem* parent);
   ~QGraphicsSpinbox();
 
-  void setValue(float r);
-  void setExecutionValue(float r);
+  void setValue(double r);
+  void setExecutionValue(double r);
   void resetExecution();
-  void setRange(float min, float max);
-  float value() const;
+  void setRange(double min, double max, double init);
+  void setNoValueChangeOnMove(bool);
+  double value() const;
 
   bool moving = false;
 
@@ -61,9 +63,10 @@ class SCORE_LIB_BASE_EXPORT QGraphicsIntSpinbox final
     , public QGraphicsItem
 {
   W_OBJECT(QGraphicsIntSpinbox)
-  Q_INTERFACES(QGraphicsItem)
+  SCORE_GRAPHICS_ITEM_TYPE(210)
   Q_DISABLE_COPY(QGraphicsIntSpinbox)
 
+  friend struct DefaultControlImpl;
   friend struct DefaultGraphicsSpinboxImpl;
   QRectF m_rect{0., 0., 40., 20.};
 
@@ -71,16 +74,18 @@ private:
   double m_value{}, m_execValue{};
   bool m_grab{};
   bool m_hasExec{};
+  bool m_noValueChangeOnMove{};
 
 public:
-  double min{}, max{};
+  double min{}, max{}, init{};
   explicit QGraphicsIntSpinbox(QGraphicsItem* parent);
   ~QGraphicsIntSpinbox();
 
   void setValue(double r);
   void setExecutionValue(double r);
   void resetExecution();
-  void setRange(double min, double max);
+  void setRange(double min, double max, double init);
+  void setNoValueChangeOnMove(bool);
   int value() const;
 
   bool moving = false;
