@@ -9,7 +9,7 @@
 #include <Audio/AudioApplicationPlugin.hpp>
 #include <Audio/AudioDevice.hpp>
 #include <Audio/AudioPreviewExecutor.hpp>
-#include <Audio/CoreAudioPortAudioInterface.hpp>
+#include <Audio/CoreAudioInterface.hpp>
 #include <Audio/DummyInterface.hpp>
 #include <Audio/GenericPortAudioInterface.hpp>
 #include <Audio/JackInterface.hpp>
@@ -187,10 +187,6 @@ std::vector<score::InterfaceBase*> score_plugin_audio::factories(
          ,
          Audio::ALSAPortAudioFactory
 #endif
-#if __has_include(<pa_mac_core.h>)
-         ,
-         Audio::CoreAudioFactory
-#endif
 #if !__has_include(<pa_asio.h>) && \
     !__has_include(<pa_win_wdmks.h>) && \
     !__has_include(<pa_win_wasapi.h>) && \
@@ -208,6 +204,10 @@ std::vector<score::InterfaceBase*> score_plugin_audio::factories(
 #if defined(OSSIA_AUDIO_PIPEWIRE)
          ,
          Audio::PipeWireAudioFactory
+#endif
+#if defined(__APPLE__) && defined(OSSIA_AUDIO_MINIAUDIO)
+         ,
+         Audio::CoreAudioFactory
 #endif
          >>(vec, ctx, key);
 
