@@ -27,17 +27,18 @@
 namespace gpp::qrhi
 {
 template <typename F>
-  requires requires { F::format(); }
 constexpr QRhiTexture::Format textureFormat()
 {
-  constexpr std::string_view fmt = F::format();
+  if constexpr(requires { std::string_view{F::format()}; })
+  {
+    constexpr std::string_view fmt = F::format();
 
-  if(fmt == "rgba" || fmt == "rgba8")
-    return QRhiTexture::RGBA8;
-  else if(fmt == "bgra" || fmt == "bgra8")
-    return QRhiTexture::BGRA8;
-  else if(fmt == "r8")
-    return QRhiTexture::R8;
+    if(fmt == "rgba" || fmt == "rgba8")
+      return QRhiTexture::RGBA8;
+    else if(fmt == "bgra" || fmt == "bgra8")
+      return QRhiTexture::BGRA8;
+    else if(fmt == "r8")
+      return QRhiTexture::R8;
 #if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
   else if(fmt == "rg8")
     return QRhiTexture::RG8;
@@ -125,107 +126,102 @@ constexpr QRhiTexture::Format textureFormat()
     return QRhiTexture::ASTC_12x12;
   else
     return QRhiTexture::RGBA8;
-}
-
-template <typename F>
-  requires std::is_enum_v<typename F::format>
-constexpr QRhiTexture::Format textureFormat()
-{
-  if constexpr(
-      requires { F::RGBA; } || requires { F::RGBA8; })
-    return QRhiTexture::RGBA8;
-  else if constexpr(
-      requires { F::BGRA; } || requires { F::BGRA8; })
-    return QRhiTexture::BGRA8;
-  else if constexpr(
-      requires { F::R8; } || requires { F::GRAYSCALE; })
-    return QRhiTexture::R8;
+  }
+  else if constexpr(std::is_enum_v<typename F::format>)
+  {
+    if constexpr(requires { F::RGBA; } || requires { F::RGBA8; })
+      return QRhiTexture::RGBA8;
+    else if constexpr(requires { F::BGRA; } || requires { F::BGRA8; })
+      return QRhiTexture::BGRA8;
+    else if constexpr(requires { F::R8; } || requires { F::GRAYSCALE; })
+      return QRhiTexture::R8;
 #if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
-  else if constexpr(requires { F::RG8; })
-    return QRhiTexture::RG8;
+    else if constexpr(requires { F::RG8; })
+      return QRhiTexture::RG8;
 #endif
-  else if constexpr(requires { F::R16; })
-    return QRhiTexture::R16;
+    else if constexpr(requires { F::R16; })
+      return QRhiTexture::R16;
 #if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
-  else if constexpr(requires { F::RG16; })
-    return QRhiTexture::RG16;
+    else if constexpr(requires { F::RG16; })
+      return QRhiTexture::RG16;
 #endif
-  else if constexpr(requires { F::RED_OR_ALPHA8; })
-    return QRhiTexture::RED_OR_ALPHA8;
-  else if constexpr(requires { F::RGBA16F; })
-    return QRhiTexture::RGBA16F;
-  else if constexpr(requires { F::RGBA32F; })
-    return QRhiTexture::RGBA32F;
-  else if constexpr(requires { F::R16F; })
-    return QRhiTexture::R16F;
-  else if constexpr(requires { F::R32F; })
-    return QRhiTexture::R32F;
+    else if constexpr(requires { F::RED_OR_ALPHA8; })
+      return QRhiTexture::RED_OR_ALPHA8;
+    else if constexpr(requires { F::RGBA16F; })
+      return QRhiTexture::RGBA16F;
+    else if constexpr(requires { F::RGBA32F; })
+      return QRhiTexture::RGBA32F;
+    else if constexpr(requires { F::R16F; })
+      return QRhiTexture::R16F;
+    else if constexpr(requires { F::R32F; })
+      return QRhiTexture::R32F;
 #if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
-  else if constexpr(requires { F::RGB10A2; })
-    return QRhiTexture::RGB10A2;
+    else if constexpr(requires { F::RGB10A2; })
+      return QRhiTexture::RGB10A2;
 #endif
-  else if constexpr(requires { F::D16; })
-    return QRhiTexture::D16;
+    else if constexpr(requires { F::D16; })
+      return QRhiTexture::D16;
 
 #if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
-  else if constexpr(requires { F::D24; })
-    return QRhiTexture::D24;
-  else if constexpr(requires { F::D24S8; })
-    return QRhiTexture::D24S8;
+    else if constexpr(requires { F::D24; })
+      return QRhiTexture::D24;
+    else if constexpr(requires { F::D24S8; })
+      return QRhiTexture::D24S8;
 #endif
-  else if constexpr(requires { F::D32F; })
-    return QRhiTexture::D32F;
+    else if constexpr(requires { F::D32F; })
+      return QRhiTexture::D32F;
 
-  else if constexpr(requires { F::BC1; })
-    return QRhiTexture::BC1;
-  else if constexpr(requires { F::BC2; })
-    return QRhiTexture::BC2;
-  else if constexpr(requires { F::BC3; })
-    return QRhiTexture::BC3;
-  else if constexpr(requires { F::BC4; })
-    return QRhiTexture::BC4;
-  else if constexpr(requires { F::BC5; })
-    return QRhiTexture::BC5;
-  else if constexpr(requires { F::BC6H; })
-    return QRhiTexture::BC6H;
-  else if constexpr(requires { F::BC7; })
-    return QRhiTexture::BC7;
-  else if(requires { F::ETC2_RGB8; })
-    return QRhiTexture::ETC2_RGB8;
-  else if(requires { F::ETC2_RGB8A1; })
-    return QRhiTexture::ETC2_RGB8A1;
-  else if(requires { F::ETC2_RGB8A8; })
-    return QRhiTexture::ETC2_RGBA8;
-  else if(requires { F::ASTC_4X4; })
-    return QRhiTexture::ASTC_4x4;
-  else if(requires { F::ASTC_5X4; })
-    return QRhiTexture::ASTC_5x4;
-  else if(requires { F::ASTC_5X5; })
-    return QRhiTexture::ASTC_5x5;
-  else if(requires { F::ASTC_6X5; })
-    return QRhiTexture::ASTC_6x5;
-  else if(requires { F::ASTC_6X6; })
-    return QRhiTexture::ASTC_6x6;
-  else if(requires { F::ASTC_8X5; })
-    return QRhiTexture::ASTC_8x5;
-  else if(requires { F::ASTC_8X6; })
-    return QRhiTexture::ASTC_8x6;
-  else if(requires { F::ASTC_8X8; })
-    return QRhiTexture::ASTC_8x8;
-  else if(requires { F::ASTC_10X5; })
-    return QRhiTexture::ASTC_10x5;
-  else if(requires { F::ASTC_10X6; })
-    return QRhiTexture::ASTC_10x6;
-  else if(requires { F::ASTC_10X8; })
-    return QRhiTexture::ASTC_10x8;
-  else if(requires { F::ASTC_10X10; })
-    return QRhiTexture::ASTC_10x10;
-  else if(requires { F::ASTC_12X10; })
-    return QRhiTexture::ASTC_12x10;
-  else if(requires { F::ASTC_12X12; })
-    return QRhiTexture::ASTC_12x12;
-  else
-    return QRhiTexture::RGBA8;
+    else if constexpr(requires { F::BC1; })
+      return QRhiTexture::BC1;
+    else if constexpr(requires { F::BC2; })
+      return QRhiTexture::BC2;
+    else if constexpr(requires { F::BC3; })
+      return QRhiTexture::BC3;
+    else if constexpr(requires { F::BC4; })
+      return QRhiTexture::BC4;
+    else if constexpr(requires { F::BC5; })
+      return QRhiTexture::BC5;
+    else if constexpr(requires { F::BC6H; })
+      return QRhiTexture::BC6H;
+    else if constexpr(requires { F::BC7; })
+      return QRhiTexture::BC7;
+    else if(requires { F::ETC2_RGB8; })
+      return QRhiTexture::ETC2_RGB8;
+    else if(requires { F::ETC2_RGB8A1; })
+      return QRhiTexture::ETC2_RGB8A1;
+    else if(requires { F::ETC2_RGB8A8; })
+      return QRhiTexture::ETC2_RGBA8;
+    else if(requires { F::ASTC_4X4; })
+      return QRhiTexture::ASTC_4x4;
+    else if(requires { F::ASTC_5X4; })
+      return QRhiTexture::ASTC_5x4;
+    else if(requires { F::ASTC_5X5; })
+      return QRhiTexture::ASTC_5x5;
+    else if(requires { F::ASTC_6X5; })
+      return QRhiTexture::ASTC_6x5;
+    else if(requires { F::ASTC_6X6; })
+      return QRhiTexture::ASTC_6x6;
+    else if(requires { F::ASTC_8X5; })
+      return QRhiTexture::ASTC_8x5;
+    else if(requires { F::ASTC_8X6; })
+      return QRhiTexture::ASTC_8x6;
+    else if(requires { F::ASTC_8X8; })
+      return QRhiTexture::ASTC_8x8;
+    else if(requires { F::ASTC_10X5; })
+      return QRhiTexture::ASTC_10x5;
+    else if(requires { F::ASTC_10X6; })
+      return QRhiTexture::ASTC_10x6;
+    else if(requires { F::ASTC_10X8; })
+      return QRhiTexture::ASTC_10x8;
+    else if(requires { F::ASTC_10X10; })
+      return QRhiTexture::ASTC_10x10;
+    else if(requires { F::ASTC_12X10; })
+      return QRhiTexture::ASTC_12x10;
+    else if(requires { F::ASTC_12X12; })
+      return QRhiTexture::ASTC_12x12;
+    else
+      return QRhiTexture::RGBA8;
+  }
 }
 
 struct DefaultPipeline
@@ -1119,6 +1115,107 @@ void prepareNewState(Node_T& eff, const Node& parent)
     eff.prepare(t);
   }
 }
+
+struct port_to_type_enum
+{
+  template <std::size_t I, avnd::cpu_texture_port F>
+  constexpr auto operator()(avnd::field_reflection<I, F> p)
+  {
+    using texture_type = std::remove_cvref_t<decltype(F::texture)>;
+    return avnd::cpu_fixed_format_texture<texture_type> ? score::gfx::Types::Image
+                                                        : score::gfx::Types::Buffer;
+  }
+  template <std::size_t I, avnd::sampler_port F>
+  constexpr auto operator()(avnd::field_reflection<I, F> p)
+  {
+    return score::gfx::Types::Image;
+  }
+  template <std::size_t I, avnd::image_port F>
+  constexpr auto operator()(avnd::field_reflection<I, F> p)
+  {
+    return score::gfx::Types::Image;
+  }
+  template <std::size_t I, avnd::attachment_port F>
+  constexpr auto operator()(avnd::field_reflection<I, F> p)
+  {
+    return score::gfx::Types::Image;
+  }
+
+  template <std::size_t I, avnd::geometry_port F>
+  constexpr auto operator()(avnd::field_reflection<I, F> p)
+  {
+    return score::gfx::Types::Geometry;
+  }
+  template <std::size_t I, avnd::mono_audio_port F>
+  constexpr auto operator()(avnd::field_reflection<I, F> p)
+  {
+    return score::gfx::Types::Audio;
+  }
+  template <std::size_t I, avnd::poly_audio_port F>
+  constexpr auto operator()(avnd::field_reflection<I, F> p)
+  {
+    return score::gfx::Types::Audio;
+  }
+  template <std::size_t I, avnd::int_parameter F>
+  constexpr auto operator()(avnd::field_reflection<I, F> p)
+  {
+    return score::gfx::Types::Int;
+  }
+  template <std::size_t I, avnd::enum_parameter F>
+  constexpr auto operator()(avnd::field_reflection<I, F> p)
+  {
+    return score::gfx::Types::Int;
+  }
+  template <std::size_t I, avnd::float_parameter F>
+  constexpr auto operator()(avnd::field_reflection<I, F> p)
+  {
+    return score::gfx::Types::Float;
+  }
+  template <std::size_t I, avnd::parameter F>
+  constexpr auto operator()(avnd::field_reflection<I, F> p)
+  {
+    using value_type = std::remove_cvref_t<decltype(F::value)>;
+
+    if constexpr(std::is_aggregate_v<value_type>)
+    {
+      constexpr int sz = boost::pfr::tuple_size_v<value_type>;
+      if constexpr(sz == 2)
+      {
+        return score::gfx::Types::Vec2;
+      }
+      else if constexpr(sz == 3)
+      {
+        return score::gfx::Types::Vec3;
+      }
+      else if constexpr(sz == 4)
+      {
+        return score::gfx::Types::Vec4;
+      }
+    }
+    return score::gfx::Types::Empty;
+  }
+  template <std::size_t I, typename F>
+  constexpr auto operator()(avnd::field_reflection<I, F> p)
+  {
+    return score::gfx::Types::Empty;
+  }
+};
+
+template <typename Node_T>
+inline void initGfxPorts(auto* self, auto& input, auto& output)
+{
+  avnd::input_introspection<Node_T>::for_all(
+      [self, &input]<typename Field, std::size_t I>(avnd::field_reflection<I, Field> f) {
+    static constexpr auto type = port_to_type_enum{}(f);
+    input.push_back(new score::gfx::Port{self, {}, type, {}});
+  });
+  avnd::output_introspection<Node_T>::for_all(
+      [self,
+       &output]<typename Field, std::size_t I>(avnd::field_reflection<I, Field> f) {
+    static constexpr auto type = port_to_type_enum{}(f);
+    output.push_back(new score::gfx::Port{self, {}, type, {}});
+  });
+}
 }
 
 #endif
