@@ -813,6 +813,8 @@ std::optional<Sampler> AudioTextureUpload::updateAudioTexture(
     if(audio.channels > 0)
     {
       int samples = audio.data.size() / audio.channels;
+      if(samples % 2 != 0)
+        samples++;
       int pixelWidth = samples / (audio.fft ? 2 : 1);
 
       float* rectUniform
@@ -958,8 +960,10 @@ void SimpleRenderedISFNode::update(RenderList& renderer, QRhiResourceUpdateBatch
   n.standardUBO.passIndex = 0;
 
   // Update audio textures
-  if(!n.m_audio_textures.empty())
+  if(!n.m_audio_textures.empty() && !m_audioTex)
+  {
     m_audioTex.emplace();
+  }
 
   for(auto& audio : n.m_audio_textures)
   {
