@@ -8,13 +8,14 @@
 
 #include <QFormLayout>
 #include <QLabel>
+#include <QUrl>
 
 #include <Spout/SpoutReceiver.h>
 
-#include <set>
-
 #include <wobjectimpl.h>
 
+#include <set>
+
 namespace Gfx::Spout
 {
 struct SpoutInputNode : score::gfx::ProcessNode
@@ -285,6 +286,11 @@ QString InputFactory::prettyName() const noexcept
   return QObject::tr("Spout Input");
 }
 
+QUrl InputFactory::manual() const noexcept
+{
+  return QUrl("https://ossia.io/score-docs/devices/spout-device.html");
+}
+
 class SpoutEnumerator : public Device::DeviceEnumerator
 {
   mutable spoutSenderNames m_senders;
