@@ -35,7 +35,7 @@ public:
 class InputSettingsWidget final : public SharedInputSettingsWidget
 {
 public:
-  InputSettingsWidget(QWidget* parent = nullptr);
+  explicit InputSettingsWidget(QWidget* parent = nullptr);
 
   Device::DeviceSettings getSettings() const override;
 };
