@@ -1,8 +1,12 @@
 #pragma once
+#include <score/document/DocumentContext.hpp>
+
 #include <QList>
 #include <QObject>
 #include <QVariant>
 
+#include <score_plugin_js_export.h>
+
 #include <memory>
 #include <optional>
 #include <verdigris>
@@ -15,10 +19,10 @@ namespace Scenario::Command
 {
 class Macro;
 }
-
 namespace JS
 {
-class EditJsContext : public QObject
+class GlobalDeviceEnumerator;
+class SCORE_PLUGIN_JS_EXPORT EditJsContext : public QObject
 {
   W_OBJECT(EditJsContext)
   using Macro = Scenario::Command::Macro;
@@ -39,10 +43,14 @@ public:
   ~EditJsContext();
 
   const score::DocumentContext* ctx();
+  W_INVOKABLE(ctx);
 
   QString deviceToJson(QString addr);
   W_SLOT(deviceToJson)
 
+  QString deviceToOSCQuery(QString addr);
+  W_SLOT(deviceToOSCQuery)
+
   void createOSCDevice(QString name, QString host, int in, int out);
   W_SLOT(createOSCDevice)
 
@@ -52,6 +60,9 @@ public:
   void createQMLSerialDevice(QString name, QString port, QString text);
   W_SLOT(createQMLSerialDevice)
 
+  GlobalDeviceEnumerator* enumerateDevices();
+  W_SLOT(enumerateDevices)
+
   void createAddress(QString addr, QString type);
   W_SLOT(createAddress)
 
@@ -192,20 +203,36 @@ public:
   void play(QObject* obj);
   W_SLOT(play, (QObject*))
 
+  void pause();
+  W_SLOT(pause, ())
+
+  void resume();
+  W_SLOT(resume, ())
+
   void stop();
   W_SLOT(stop)
 
-  // File API
+  void scrub(double z);
+  W_SLOT(scrub)
+
+  /// File API ///
   QString readFile(QString path);
   W_SLOT(readFile)
 
+  /// Score UI ///
   QObject* selectedObject();
   W_SLOT(selectedObject)
 
   QVariantList selectedObjects();
   W_SLOT(selectedObjects)
 
-  /// UI ///
+  void zoom(double zx, double zy);
+  W_SLOT(zoom, (double, double));
+
+  void scroll(double zx, double zy);
+  W_SLOT(scroll, (double, double));
+
+  /// Custom UI ///
   QVariant prompt(QVariant v);
   W_SLOT(prompt)
 
@@ -216,3 +243,4 @@ private:
 
 W_REGISTER_ARGTYPE(QVector<QVariantList>)
 W_REGISTER_ARGTYPE(QList<QObject*>)
+W_REGISTER_ARGTYPE(JS::GlobalDeviceEnumerator*)
