@@ -17,6 +17,8 @@ class pattern_node : public ossia::nonowning_graph_node
 {
 public:
   ossia::midi_outlet out;
+  ossia::value_outlet accent_out;
+  ossia::value_outlet slide_out;
   Pattern pattern;
   ossia::flat_set<uint8_t> in_flight;
 
@@ -28,10 +30,20 @@ public:
   {
     in_flight.reserve(32);
     m_outlets.push_back(&out);
+    m_outlets.push_back(&accent_out);
+    m_outlets.push_back(&slide_out);
   }
 
   std::string label() const noexcept override { return "pattern_node"; }
 
+  bool legato(int note) const noexcept
+  {
+    for(const Lane& lane : pattern.lanes)
+      if(lane.note == note)
+        return lane.pattern[current] == Note::Legato;
+    return false;
+  }
+
   void run(const ossia::token_request& tk, ossia::exec_state_facade st) noexcept override
   {
     using namespace ossia;
@@ -45,6 +57,7 @@ public:
         mess.push_back(libremidi::channel_events::note_off(channel, note, 0));
         mess.back().timestamp = 0;
       }
+      in_flight.clear();
       return;
     }
 
@@ -56,22 +69,74 @@ public:
 
       last = current;
       auto& mess = out.target<ossia::midi_port>()->messages;
-      for(uint8_t note : in_flight)
+
+      for(auto it = in_flight.begin(); it != in_flight.end();)
       {
-        mess.push_back(libremidi::channel_events::note_off(channel, note, 0));
-        mess.back().timestamp = date;
+        uint8_t note = *it;
+        if(!legato(note))
+        {
+          mess.push_back(libremidi::channel_events::note_off(channel, note, 0));
+          mess.back().timestamp = date;
+          it = in_flight.erase(it);
+        }
+        else
+        {
+          ++it;
+        }
       }
-      in_flight.clear();
 
       for(Lane& lane : pattern.lanes)
       {
-        if(lane.pattern[current])
+        if(lane.note <= 127)
         {
-          mess.push_back(libremidi::channel_events::note_on(channel, lane.note, 64));
-          mess.back().timestamp = date;
-          in_flight.insert(lane.note);
+          switch(lane.pattern[current])
+          {
+            case Note::Note:
+              mess.push_back(
+                  libremidi::channel_events::note_on(channel, lane.note, 100));
+              mess.back().timestamp = date;
+              in_flight.insert(lane.note);
+              break;
+            case Note::Legato:
+              if(!in_flight.contains(lane.note))
+              {
+                mess.push_back(
+                    libremidi::channel_events::note_on(channel, lane.note, 100));
+                mess.back().timestamp = date;
+                in_flight.insert(lane.note);
+              }
+              break;
+            case Note::Rest:
+              if(in_flight.contains(lane.note))
+              {
+                mess.push_back(
+                    libremidi::channel_events::note_off(channel, lane.note, 0));
+                mess.back().timestamp = date;
+                in_flight.erase(lane.note);
+              }
+              break;
+          }
         }
       }
+
+      for(Lane& lane : pattern.lanes)
+      {
+        if(lane.note == 255)
+        {
+          if(lane.pattern[current] != Note::Rest)
+            accent_out->write_value(1., date);
+          else
+            accent_out->write_value(0., date);
+        }
+        else if(lane.note == 254)
+        {
+          if(lane.pattern[current] != Note::Rest)
+            slide_out->write_value(1., date);
+          else
+            slide_out->write_value(0., date);
+        }
+      }
+
       current = (current + 1) % pattern.length;
     }
   }
