@@ -2,6 +2,8 @@
 #if defined(OSSIA_PROTOCOL_SIMPLEIO)
 #include "SimpleIOSpecificSettings.hpp"
 
+#include <score/application/ApplicationComponents.hpp>
+#include <score/plugins/SerializableHelpers.hpp>
 #include <score/serialization/DataStreamVisitor.hpp>
 #include <score/serialization/JSONVisitor.hpp>
 #include <score/serialization/StdVariantSerialization.hpp>
@@ -16,12 +18,14 @@ JSON_METADATA(Protocols::SimpleIO::Custom, "Custom")
 template <>
 void DataStreamReader::read(const Protocols::SimpleIO::GPIO& n)
 {
+  m_stream << n.chip << n.direction << n.events << n.flags << n.line << n.state;
   insertDelimiter();
 }
 
 template <>
 void DataStreamWriter::write(Protocols::SimpleIO::GPIO& n)
 {
+  m_stream >> n.chip >> n.direction >> n.events >> n.flags >> n.line >> n.state;
   checkDelimiter();
 }
 
@@ -103,12 +107,14 @@ void JSONWriter::write(Protocols::SimpleIO::DAC& n)
 template <>
 void DataStreamReader::read(const Protocols::SimpleIO::PWM& n)
 {
+  m_stream << n.chip << n.channel << n.polarity;
   insertDelimiter();
 }
 
 template <>
 void DataStreamWriter::write(Protocols::SimpleIO::PWM& n)
 {
+  m_stream >> n.chip >> n.channel >> n.polarity;
   checkDelimiter();
 }
 
@@ -116,12 +122,20 @@ template <>
 void JSONReader::read(const Protocols::SimpleIO::PWM& n)
 {
   stream.StartObject();
+  obj["Chip"] = n.chip;
+  obj["Channel"] = n.channel;
+  obj["Polarity"] = n.polarity;
   stream.EndObject();
 }
 
 template <>
 void JSONWriter::write(Protocols::SimpleIO::PWM& n)
 {
+  if(!obj.tryGet("Chip"))
+    return;
+  n.chip = obj["Chip"].toInt();
+  n.channel = obj["Channel"].toInt();
+  n.polarity = obj["Polarity"].toInt();
 }
 
 template <>
