@@ -76,6 +76,9 @@ EffectProcessFactory_T<vst::Model>::descriptor(QString d) const noexcept
 
   auto it = ossia::find_if(
       app.vst_infos, [d](const vst::VSTInfo& vst) { return vst.uniqueID == d.toInt(); });
+  desc.documentationLink = QUrl(
+      "https://ossia.io/score-docs/processes/"
+      "audio-plugins.html#common-formats-vst-vst3-lv2-jsfx");
   if(it != app.vst_infos.end())
   {
     desc.prettyName = it->displayName;
@@ -106,6 +109,13 @@ EffectProcessFactory_T<vst::Model>::descriptor(QString d) const noexcept
   }
   return desc;
 }
+
+template <>
+Process::Descriptor EffectProcessFactory_T<vst::Model>::descriptor(
+    const Process::ProcessModel& d) const noexcept
+{
+  return descriptor(d.effect());
+}
 }
 
 namespace vst
@@ -277,7 +287,9 @@ void Model::on_addControl_impl(ControlInlet* ctrl)
 {
   connect(
       ctrl, &ControlInlet::valueChanged, this,
-      [this, i = ctrl->fxNum](float newval) { on_controlChangedFromScore(i, newval); });
+      [this, i = ctrl->fxNum](const ossia::value& newval) {
+    on_controlChangedFromScore(i, ossia::convert<float>(newval));
+  });
 
   {
     /*
@@ -725,8 +737,10 @@ void Model::load()
     auto inlet = safe_cast<ControlInlet*>(m_inlets[i]);
     int ctrl = inlet->fxNum;
 
-    connect(inlet, &ControlInlet::valueChanged, this, [this, ctrl](float newval) {
-      on_controlChangedFromScore(ctrl, newval);
+    connect(
+        inlet, &ControlInlet::valueChanged, this,
+        [this, ctrl](const ossia::value& newval) {
+      on_controlChangedFromScore(ctrl, ossia::convert<float>(newval));
     });
     controls.insert({ctrl, inlet});
   }
